==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RecreateDeploymentStrategyParamsFluentImpl<A extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>{
  public RecreateDeploymentStrategyParamsFluentImpl() {
  }
  public RecreateDeploymentStrategyParamsFluentImpl(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this.withMid(instance.getMid()); 
    this.withPost(instance.getPost()); 
    this.withPre(instance.getPre()); 
    this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.LifecycleHookBuilder mid;
  private io.fabric8.openshift.api.model.LifecycleHookBuilder post;
  private io.fabric8.openshift.api.model.LifecycleHookBuilder pre;
  private java.lang.Long timeoutSeconds;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMid instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getMid() {
    return this.mid!=null?this.mid.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildMid() {
    return this.mid!=null?this.mid.build():null;
  }
  public A withMid(io.fabric8.openshift.api.model.LifecycleHook mid) {
    _visitables.get("mid").remove(this.mid);
    if (mid!=null){ this.mid= new io.fabric8.openshift.api.model.LifecycleHookBuilder(mid); _visitables.get("mid").add(this.mid);} return (A) this;
  }
  public java.lang.Boolean hasMid() {
    return this.mid != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMid() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.MidNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.MidNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editMid() {
    return withNewMidLike(getMid());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMid() {
    return withNewMidLike(getMid() != null ? getMid(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewMidLike(getMid() != null ? getMid(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost() {
    return this.post!=null?this.post.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildPost() {
    return this.post!=null?this.post.build():null;
  }
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post) {
    _visitables.get("post").remove(this.post);
    if (post!=null){ this.post= new io.fabric8.openshift.api.model.LifecycleHookBuilder(post); _visitables.get("post").add(this.post);} return (A) this;
  }
  public java.lang.Boolean hasPost() {
    return this.post != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPost() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PostNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PostNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editPost() {
    return withNewPostLike(getPost());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost() {
    return withNewPostLike(getPost() != null ? getPost(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewPostLike(getPost() != null ? getPost(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre() {
    return this.pre!=null?this.pre.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildPre() {
    return this.pre!=null?this.pre.build():null;
  }
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre) {
    _visitables.get("pre").remove(this.pre);
    if (pre!=null){ this.pre= new io.fabric8.openshift.api.model.LifecycleHookBuilder(pre); _visitables.get("pre").add(this.pre);} return (A) this;
  }
  public java.lang.Boolean hasPre() {
    return this.pre != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPre() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PreNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PreNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editPre() {
    return withNewPreLike(getPre());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre() {
    return withNewPreLike(getPre() != null ? getPre(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewPreLike(getPre() != null ? getPre(): item);
  }
  public java.lang.Long getTimeoutSeconds() {
    return this.timeoutSeconds;
  }
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds) {
    this.timeoutSeconds=timeoutSeconds; return (A) this;
  }
  public java.lang.Boolean hasTimeoutSeconds() {
    return this.timeoutSeconds != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecreateDeploymentStrategyParamsFluentImpl that = (RecreateDeploymentStrategyParamsFluentImpl) o;
    if (mid != null ? !mid.equals(that.mid) :that.mid != null) return false;
    if (post != null ? !post.equals(that.post) :that.post != null) return false;
    if (pre != null ? !pre.equals(that.pre) :that.pre != null) return false;
    if (timeoutSeconds != null ? !timeoutSeconds.equals(that.timeoutSeconds) :that.timeoutSeconds != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mid,  post,  pre,  timeoutSeconds,  additionalProperties,  super.hashCode());
  }
  public class MidNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MidNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    MidNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withMid(builder.build());
    }
    public N endMid() {
      return and();
    }
    
  }
  public class PostNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PostNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    PostNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPost(builder.build());
    }
    public N endPost() {
      return and();
    }
    
  }
  public class PreNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PreNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    PreNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPre(builder.build());
    }
    public N endPre() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RecreateDeploymentStrategyParamsFluentImpl<A extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>{
  public RecreateDeploymentStrategyParamsFluentImpl() {
  }
  public RecreateDeploymentStrategyParamsFluentImpl(io.fabric8.openshift.api.model.RecreateDeploymentStrategyParams instance) {
    this.withMid(instance.getMid()); 
    this.withPost(instance.getPost()); 
    this.withPre(instance.getPre()); 
    this.withTimeoutSeconds(instance.getTimeoutSeconds()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.LifecycleHookBuilder mid;
  private io.fabric8.openshift.api.model.LifecycleHookBuilder post;
  private io.fabric8.openshift.api.model.LifecycleHookBuilder pre;
  private java.lang.Long timeoutSeconds;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMid instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getMid() {
    return this.mid!=null?this.mid.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildMid() {
    return this.mid!=null?this.mid.build():null;
  }
  public A withMid(io.fabric8.openshift.api.model.LifecycleHook mid) {
    _visitables.get("mid").remove(this.mid);
    if (mid!=null){ this.mid= new io.fabric8.openshift.api.model.LifecycleHookBuilder(mid); _visitables.get("mid").add(this.mid);} return (A) this;
  }
  public java.lang.Boolean hasMid() {
    return this.mid != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMid() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.MidNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.MidNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editMid() {
    return withNewMidLike(getMid());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMid() {
    return withNewMidLike(getMid() != null ? getMid(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewMidLike(getMid() != null ? getMid(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost() {
    return this.post!=null?this.post.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildPost() {
    return this.post!=null?this.post.build():null;
  }
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post) {
    _visitables.get("post").remove(this.post);
    if (post!=null){ this.post= new io.fabric8.openshift.api.model.LifecycleHookBuilder(post); _visitables.get("post").add(this.post);} return (A) this;
  }
  public java.lang.Boolean hasPost() {
    return this.post != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPost() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PostNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PostNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editPost() {
    return withNewPostLike(getPost());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost() {
    return withNewPostLike(getPost() != null ? getPost(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewPostLike(getPost() != null ? getPost(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre() {
    return this.pre!=null?this.pre.build():null;
  }
  public io.fabric8.openshift.api.model.LifecycleHook buildPre() {
    return this.pre!=null?this.pre.build():null;
  }
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre) {
    _visitables.get("pre").remove(this.pre);
    if (pre!=null){ this.pre= new io.fabric8.openshift.api.model.LifecycleHookBuilder(pre); _visitables.get("pre").add(this.pre);} return (A) this;
  }
  public java.lang.Boolean hasPre() {
    return this.pre != null;
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPre() {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PreNestedImpl();
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return new io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluentImpl.PreNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editPre() {
    return withNewPreLike(getPre());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre() {
    return withNewPreLike(getPre() != null ? getPre(): new io.fabric8.openshift.api.model.LifecycleHookBuilder().build());
  }
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item) {
    return withNewPreLike(getPre() != null ? getPre(): item);
  }
  public java.lang.Long getTimeoutSeconds() {
    return this.timeoutSeconds;
  }
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds) {
    this.timeoutSeconds=timeoutSeconds; return (A) this;
  }
  public java.lang.Boolean hasTimeoutSeconds() {
    return this.timeoutSeconds != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecreateDeploymentStrategyParamsFluentImpl that = (RecreateDeploymentStrategyParamsFluentImpl) o;
    if (mid != null ? !mid.equals(that.mid) :that.mid != null) return false;
    if (post != null ? !post.equals(that.post) :that.post != null) return false;
    if (pre != null ? !pre.equals(that.pre) :that.pre != null) return false;
    if (timeoutSeconds != null ? !timeoutSeconds.equals(that.timeoutSeconds) :that.timeoutSeconds != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mid,  post,  pre,  timeoutSeconds,  additionalProperties,  super.hashCode());
  }
  public class MidNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MidNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    MidNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withMid(builder.build());
    }
    public N endMid() {
      return and();
    }
    
  }
  public class PostNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PostNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    PostNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPost(builder.build());
    }
    public N endPost() {
      return and();
    }
    
  }
  public class PreNestedImpl<N> extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>> implements io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PreNestedImpl(io.fabric8.openshift.api.model.LifecycleHook item) {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this, item);
    }
    PreNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.LifecycleHookBuilder(this);
    }
    io.fabric8.openshift.api.model.LifecycleHookBuilder builder;
    public N and() {
      return (N) RecreateDeploymentStrategyParamsFluentImpl.this.withPre(builder.build());
    }
    public N endPre() {
      return and();
    }
    
  }
  
}
